@@ -1,4 +1,6 @@
-/* GDM - The GNOME Display Manager
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -16,7 +18,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <config.h>
+#include "config.h"
+
 #include <glib/gi18n.h>
 #include <syslog.h>
 #include <signal.h>
@@ -154,7 +157,7 @@ gdm_display_check_loop (GdmDisplay *disp)
       disp->last_start_time = now;
     }
 
-  disp->retry_count ++;
+  disp->retry_count++;
 
   return TRUE;
 }
@@ -200,7 +203,7 @@ wait_again:
 		    /* rekill the slave to tell it to
 		       hurry up and die if we're getting
 		       killed ourselves */
-		    if ((gdm_signal_terminthup_was_notified()) ||
+		    if ((gdm_signal_terminthup_was_notified ()) ||
 			(t + 10 <= time (NULL))) {
 			    gdm_debug ("whack_old_slave: GOT ANOTHER SIGTERM (or it was 10 secs already), killing slave again with SIGKILL");
 			    t = time (NULL);
@@ -316,6 +319,8 @@ gdm_display_manage (GdmDisplay *d)
 
 	d->slave_notify_fd = fds[0];
 
+	fcntl (d->slave_notify_fd, F_SETFL, fcntl (d->slave_notify_fd, F_GETFL) | O_NONBLOCK);
+
 	gdm_slave_start (d);
 	/* should never retern */
 
@@ -367,7 +372,6 @@ gdm_display_manage (GdmDisplay *d)
  *
  * Stop services for a display
  */
-
 void
 gdm_display_unmanage (GdmDisplay *d)
 {
@@ -386,7 +390,7 @@ gdm_display_unmanage (GdmDisplay *d)
     whack_old_slave (d, TRUE /* kill_connection */);
     
     d->dispstat = DISPLAY_DEAD;
-    if (d->type != TYPE_STATIC)
+    if (d->type != TYPE_STATIC || d->removeconf)
 	gdm_display_dispose (d);
 
     gdm_debug ("gdm_display_unmanage: Display stopped");
@@ -408,12 +412,12 @@ count_session_limits (void)
 		GdmDisplay *d = li->data;
 		if (SERVER_IS_XDMCP (d)) {
 			if (d->dispstat == XDMCP_MANAGED)
-				xdmcp_sessions ++;
+				xdmcp_sessions++;
 			else if (d->dispstat == XDMCP_PENDING)
-				xdmcp_pending ++;
+				xdmcp_pending++;
 		}
 		if (SERVER_IS_FLEXI (d)) {
-			flexi_servers ++;
+			flexi_servers++;
 		}
 	}
 }
@@ -482,14 +486,14 @@ gdm_display_dispose (GdmDisplay *d)
 
     if (d->type == TYPE_XDMCP_PROXY) {
 	    if (d->parent_auth_file != NULL) {
-		    VE_IGNORE_EINTR (unlink (d->parent_auth_file));
+		    VE_IGNORE_EINTR (g_unlink (d->parent_auth_file));
 	    }
 	    g_free (d->parent_auth_file);
 	    d->parent_auth_file = NULL;
     }
 
     if (d->parent_temp_auth_file != NULL) {
-	    VE_IGNORE_EINTR (unlink (d->parent_temp_auth_file));
+	    VE_IGNORE_EINTR (g_unlink (d->parent_temp_auth_file));
     }
     g_free (d->parent_temp_auth_file);
     d->parent_temp_auth_file = NULL;
@@ -529,6 +533,9 @@ gdm_display_dispose (GdmDisplay *d)
     g_free (d->login);
     d->login = NULL;
 
+    g_free (d->preset_user);
+    d->preset_user = NULL;
+
     g_free (d->xsession_errors_filename);
     d->xsession_errors_filename = NULL;
 
